pygeodesy.unitsBase.Radius

Package pygeodesy :: Module unitsBase :: Class Radius |
[frames] | no frames]

# Class Radius

          object --+
                   |
               float --+
                       |
      object --+       |
               |       |
    named._Named --+   |
                   |   |
          _NamedUnit --+
                       |
                   Float --+
                           |
                          Radius

Named `float` representing a radius, conventionally in `meter`.

Instance Methods
Inherited from `Float`: `__repr__`, `__str__`, `toRepr`, `toStr` Inherited from `float`: `__abs__`, `__add__`, `__coerce__`, `__div__`, `__divmod__`, `__eq__`, `__float__`, `__floordiv__`, `__format__`, `__ge__`, `__getattribute__`, `__getformat__`, `__getnewargs__`, `__gt__`, `__hash__`, `__int__`, `__le__`, `__long__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__neg__`, `__nonzero__`, `__pos__`, `__pow__`, `__radd__`, `__rdiv__`, `__rdivmod__`, `__rfloordiv__`, `__rmod__`, `__rmul__`, `__rpow__`, `__rsub__`, `__rtruediv__`, `__setformat__`, `__sub__`, `__truediv__`, `__trunc__`, `as_integer_ratio`, `conjugate`, `fromhex`, `hex`, `is_integer` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, arg=None, name=`'``radius``'`, **Error_name_arg) New Radius instance, see Float. |

Properties
Inherited from `Float`: `isneg0` Inherited from `float`: `imag`, `real` Inherited from `_NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, arg=None, name=`'``radius``'`, **Error_name_arg) Static Method |
New Radius instance, see Float. Arguments: `arg` - The value (any `type` acceptable to `float`). `name` - Optional name (`str`). `Error_name_arg` - Optional `Error=UnitError` to raise and optional `name=arg` keyword argument, inlieu of separate `arg` and `name` ones. Returns: a new object with type S, a subtype of T A named `Float`. Raises: `Error` - Invalid `arg`. Overrides: object.__new__